<?php

namespace App\Http\Controllers;

use App\Models\Availiabilities;
use App\Models\Bookings;
use App\Models\Cart;
use App\Models\Categories;
use App\Models\ContactMessage;
use App\Models\OrderDetails;
use App\Models\Orders;
use App\Models\Products;
use App\Models\Promocodes;
use App\Models\Setting;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Carbon\Carbon;

class WebsiteController extends Controller
{
    public function home()
    {
        $products = Products::orderBy('id', 'desc')->paginate(6);
        $randomproducts = Products::inRandomOrder()->limit(6)->get();
        return view("website.home",compact('products','randomproducts'));
    }
    public function contact()
    {
        return view("website.contact");
    }
    public function about()
    {
        return view("website.about");
    }
    public function privacy()
    {
        return view("website.privacy");
    }
    public function terms()
    {
        return view("website.terms");
    }
    public function faq()
    {
        return view("website.faq");
    }
    public function shop()
    {
        $products = Products::inRandomOrder()->orderBy('id', 'desc')->paginate(12);
        return view("website.shop", compact('products'));
    }
    public function details($slug)
    {
        $product = Products::where('slug',$slug)->first();
        return view("website.details",compact('product'));
    }
    public function appointment()
    {
        $availabilities = Availiabilities::where('status',"1")->get();
        return view("website.appointment",compact('availabilities'));
    }

    public function contactus()
    {
        $system = Setting::first();
        return view("website.contactus", compact('system'));
    }

    public function save_bookings(Request $request)
    {
//        dd($request->all());
        $validator = Validator::make($request->all(), [
            'fname' => 'required',
            'lname' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'date' => 'required',
            'time' => 'required',
            'message' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator)->with('error', 'All fields required.');
        }

        $data['fname'] = $request->fname;
        $data['lname'] = $request->lname;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['date'] = $request->date;
        $data['time'] = $request->time;
        $data['message'] = $request->message;
        if(isset($request->productid) && !empty($request->productid))
        {
            $data['productid'] = $request->productid;
        }
        Bookings::create($data);
        return redirect()->back()->with('success', 'Successfully Submitted.');

    }

    public function gettime(Request $request)
    {
        if(isset($request->date) && !empty($request->date))
        {
            $date = Carbon::parse($request->date)->format('Y-m-d');
        }
        else
        {
            $date = Carbon::now();
        }
        $availabilities = Availiabilities::where('status',"1")->get();
        $activeBookingsTime = Bookings::where('status','active')->whereDate('date', $date)->pluck('time')->toArray();
        return view("website.gettime",compact('availabilities','activeBookingsTime','date'));
    }

    public function save_contact_message(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'subject' => 'required',
            'message' => 'required'
        ]);
        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator);
        }

        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['subject'] = $request->subject;
        $data['phone'] = $request->phone;
        $data['message'] = $request->message;
        $check = ContactMessage::create($data);
        return redirect()->back()->with('success', 'Successfully Submitted.');

    }

    public function cart()
    {
        $carts = Cart::where('userid', Auth::guard('web')->user()->id)->get();
        return view("website.cart", compact('carts'));
    }

    public function delete_cart_product($id)
    {
        $carts = Cart::findOrFail($id)->delete();
        return redirect()->back()->with('success', 'Successfully Deleted.');
    }

    public function update_cart(Request $request)
    {
        foreach ($request->quantity as $productid => $quan) {
            $checkProduct = Cart::where('userid', Auth::guard('web')->user()->id)->where('productid', $productid)->first();
            $checkProduct->quantity = $quan;
            $checkProduct->update();
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function checkout()
    {
        $count = Cart::where('userid', Auth::guard('web')->user()->id)->count();
        if ($count > 0) {
            $carts = Cart::where('userid', Auth::guard('web')->user()->id)->get();
            return view("website.checkout", compact('carts'));
        } else {
            return redirect()->back()->with('error', 'Please add some products in cart.');
        }
    }

    public function save_order(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'fname' => 'required',
            'lname' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'address' => 'required',
            'city' => 'required',
            'total_price_of_cart' => 'required',
            'total_price' => 'required',
            'zipcode' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->with('error', 'All Fields Required.');
        }
        $order_idd = rand(1000, 1000000);
        $data['userid'] = Auth::guard('web')->user()->id;
        $data['orderid'] = $order_idd;
        $data['fname'] = $request->fname;
        $data['lname'] = $request->lname;
        $data['email'] = $request->email;
        $data['phone'] = $request->phone;
        $data['address'] = $request->address;
        $data['city'] = $request->city;
        $data['zipcode'] = $request->zipcode;
        $data['price'] = $request->total_price_of_cart;
        $data['total_price'] = $request->total_price;
        if (isset($request->promocode) && !empty($request->promocode)) {
            $pro = Promocodes::where('name', 'like', '%' . $request->promocode . '%')->first();
            $data['promocode'] = $request->promocode;
            $data['discount'] = $pro->discount;
        }
        $orderData = Orders::create($data);

        $carts = Cart::where('userid', Auth::guard('web')->user()->id)->get();
        foreach ($carts as $cart) {
            $data_Detail['orderid'] = $orderData->id;
            $data_Detail['productid'] = $cart->productdata->id;
            $data_Detail['product_name'] = $cart->productdata->name;
            $data_Detail['product_price'] = $cart->productdata->price;
            $data_Detail['quantity'] = $cart->quantity;
            OrderDetails::create($data_Detail);
        }
        Cart::where('userid', Auth::guard('web')->user()->id)->delete();
        return redirect()->route('thankyou', [$order_idd])->with('success', 'Order Placed.');
    }

    public function thankyou($orderid)
    {
        return view('website.thankyou', compact('orderid'));
    }

    // public function Shop(Request $request)
    // {
    //     $query = Products::query();
    //     if (isset($request->categoryid) && !empty($request->categoryid)) {
    //         $query->where('categoryid', $request->categoryid);
    //     }
    //     if (isset($request->name) && !empty($request->name)) {
    //         $query->where('name', 'like', '%' . $request->name . '%');
    //     }
    //     $products = $query->orderBy('id', 'desc')->paginate(12);
    //     return view("website.Shop", compact('products'));
    // }

    public function product_detail($slug)
    {
        $product = Products::where('slug', $slug)->first();
        return view("website.product_detail", compact('product'));
    }

    public function login()
    {
        if (Auth::guard('web')->check()) {
            return redirect()->route('/');

        } else {
            return view("website.login");
        }
    }

    public function customerlogout(Request $request)
    {
        Auth::guard('web')->logout();
        return redirect()->route("/");
    }

    public function customerlogin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required',
            'password' => 'required|min:8'
        ]);
        if ($validator->fails()) {
            return back()->withInput()->withErrors($validator);
        }
        if (Auth::guard('web')->attempt(['email' => $request->email, 'password' => $request->password, 'type' => 'user'])) {
            if (Auth::guard('web')->user()->status == "inactive") {
                Auth::guard('web')->logout();
                return redirect()->back()->with('error', 'Account Inactive / Blocked ! Please Contact with Customer support.')->withErrors("Account Inactive / Blocked ! Please Contact with Customer support.");
            } else {
                if (Auth::guard('web')->check()) {
                    return redirect()->route('/');
                }
            }
        } else {
            return redirect()->back()->with('error', 'Invalid Email or Password !')->withInput()->withErrors("Invalid Email or Password !");
        }
    }

    public function save_register_user(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required|unique:users,email',
            'password' => 'min:8|required'
        ]);
        if ($validator->fails()) {
            return back()
                ->withInput()
                ->withErrors($validator);
        }
        $data['name'] = $request->name;
        $data['email'] = $request->email;
        $data['status'] = "active";
        $data['password'] = Hash::make($request->password);
        $userdata = User::create($data);
        return redirect()->route('login')->with('success', 'Successfully Registered.');
    }

    public function profile()
    {
        $user = User::findOrFail(Auth::guard('web')->user()->id);
        return view("website.pofile", compact("user"));
    }

    public function updateuserprofile(Request $request)
    {
        $GetData = User::findOrFail(Auth::guard('web')->user()->id);
        if (isset($request->name)) {
            $GetData->name = $request->name;
        }
        if (isset($request->email) && !empty($request->email)) {
            $validator = Validator::make($request->all(), [
                'email' => [
                    'required',
                    Rule::unique('users')->ignore(Auth::guard('web')->user()->id),
                ],
            ]);
            if ($validator->fails()) {
                return back()->with('error', 'Email already exist.');
            }
        }
        if (isset($request->phone)) {
            $GetData->phone = $request->phone;
        }
        if (isset($request->address)) {
            $GetData->address = $request->address;
        }
        if (isset($request->password)) {

            $validator = Validator::make($request->all(), [
                'password' => 'required|string|min:8'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Please Enter Valid Password !');
            }
            $GetData->password = Hash::make($request->password);
        }

        $GetData->save();
        return back()->with('success', 'Profile Updated Successfully !');
    }

    public function add_to_cart_single($productid)
    {
        $check = Cart::where('userid', Auth::guard('web')->user()->id)->where('productid', $productid)->count();
        if ($check > 0) {
            $checkProduct = Cart::where('userid', Auth::guard('web')->user()->id)->where('productid', $productid)->first();
            $checkProduct->quantity = ($checkProduct->quantity + 1);
            $checkProduct->update();
        } else {
            $data['userid'] = Auth::guard('web')->user()->id;
            $data['productid'] = $productid;
            $data['quantity'] = 1;
            Cart::create($data);
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function add_to_cart_multiple($quantity, $productid)
    {
        $check = Cart::where('userid', Auth::guard('web')->user()->id)->where('productid', $productid)->count();
        if ($check > 0) {
            $checkProduct = Cart::where('userid', Auth::guard('web')->user()->id)->where('productid', $productid)->first();
            $checkProduct->quantity = $quantity;
            $checkProduct->update();
        } else {
            $data['userid'] = Auth::guard('web')->user()->id;
            $data['productid'] = $productid;
            $data['quantity'] = $quantity;
            Cart::create($data);
        }
        return redirect()->back()->with('success', 'Successfully Added.');
    }

    public function check_promocode_from_database(Request $request)
    {
        $promocode = $request->promocode;
        $total_price_of_cart = $request->total_price_of_cart;

        $pro = Promocodes::where('name', 'like', '%' . $request->promocode . '%')->first();
        if (!empty($pro)) {
            $result = ($pro->discount / 100) * $total_price_of_cart;
            $f = $total_price_of_cart - $result;
            $final_price = intval($f);
            return response()->json(['success' => true, 'final_price' => $final_price]);
        } else {
            return response()->json(['success' => false, 'final_price' => $total_price_of_cart]);
        }

    }

    public function orderhistory()
    {
        $orders = Orders::where('userid', Auth::guard('web')->user()->id)->get();
        return view("website.orderhistory", compact("orders"));
    }

}
